package cn.com.infosec.ocsp.test;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.x509.AuthorityKeyIdentifier;
import cn.com.infosec.asn1.x509.BasicConstraints;
import cn.com.infosec.asn1.x509.SubjectKeyIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.x509.X509V3CertificateGenerator;
import java.io.ByteArrayInputStream;
import java.math.BigInteger;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.cert.X509Certificate;
import java.util.Date;
import javax.crypto.KeyGenerator;

public class OCSPTestUtil {
   public static SecureRandom rand;
   public static KeyPairGenerator kpg;
   public static KeyPairGenerator eckpg;
   public static KeyGenerator desede128kg;
   public static KeyGenerator desede192kg;
   public static KeyGenerator rc240kg;
   public static KeyGenerator rc264kg;
   public static KeyGenerator rc2128kg;
   public static BigInteger serialNumber;
   public static final boolean DEBUG = true;

   static {
      Exception var10000;
      label29: {
         boolean var10001;
         KeyPairGenerator var4;
         try {
            rand = new SecureRandom();
            var4 = kpg = KeyPairGenerator.getInstance("RSA", "INFOSEC");
         } catch (Exception var3) {
            var10000 = var3;
            var10001 = false;
            break label29;
         }

         short var5 = 1024;

         try {
            var4.initialize(var5, rand);
            serialNumber = new BigInteger("1");
            var4 = eckpg = KeyPairGenerator.getInstance("ECDSA", "INFOSEC");
         } catch (Exception var2) {
            var10000 = var2;
            var10001 = false;
            break label29;
         }

         var5 = 192;

         try {
            var4.initialize(var5, rand);
            return;
         } catch (Exception var1) {
            var10000 = var1;
            var10001 = false;
         }
      }

      Exception var0 = var10000;
      throw new RuntimeException(var0.toString());
   }

   public static KeyPair makeKeyPair() {
      return kpg.generateKeyPair();
   }

   public static KeyPair makeECKeyPair() {
      return eckpg.generateKeyPair();
   }

   public static X509Certificate makeCertificate(KeyPair _subKP, String _subDN, KeyPair _issKP, String _issDN) {
      return makeCertificate(_subKP, _subDN, _issKP, _issDN, false);
   }

   public static X509Certificate makeECDSACertificate(KeyPair _subKP, String _subDN, KeyPair _issKP, String _issDN) {
      return makeECDSACertificate(_subKP, _subDN, _issKP, _issDN, false);
   }

   public static X509Certificate makeCACertificate(KeyPair _subKP, String _subDN, KeyPair _issKP, String _issDN) {
      return makeCertificate(_subKP, _subDN, _issKP, _issDN, true);
   }

   public static X509Certificate makeCertificate(KeyPair _subKP, String _subDN, KeyPair _issKP, String _issDN, boolean _ca) {
      return makeCertificate(_subKP, _subDN, _issKP, _issDN, "MD5withRSA", _ca);
   }

   public static X509Certificate makeECDSACertificate(KeyPair _subKP, String _subDN, KeyPair _issKP, String _issDN, boolean _ca) {
      return makeCertificate(_subKP, _subDN, _issKP, _issDN, "SHA1WithECDSA", _ca);
   }

   public static X509Certificate makeCertificate(KeyPair _subKP, String _subDN, KeyPair _issKP, String _issDN, String algorithm, boolean _ca) {
      KeyPair var10000 = _issKP;
      PublicKey _subKP1 = _subKP.getPublic();
      PrivateKey _issKP1 = _issKP.getPrivate();
      PublicKey var6 = var10000.getPublic();
      X509V3CertificateGenerator var7;
      X509V3CertificateGenerator var14 = var7 = new X509V3CertificateGenerator;
      PublicKey var10006 = _subKP1;
      var7.<init>();
      var7.reset();
      var7.setSerialNumber(allocateSerialNumber());
      var7.setIssuerDN(new X509Name(_issDN));
      var7.setNotBefore(new Date(System.currentTimeMillis()));
      var7.setNotAfter(new Date(System.currentTimeMillis() + 8640000000L));
      var7.setSubjectDN(new X509Name(_subDN));
      var7.setPublicKey(_subKP1);
      var7.setSignatureAlgorithm(algorithm);
      DERObjectIdentifier _subKP2 = X509Extensions.SubjectKeyIdentifier;
      SubjectKeyIdentifier _subDN1 = createSubjectKeyId(var10006);
      var7.addExtension(_subKP2, false, _subDN1);
      _subKP2 = X509Extensions.AuthorityKeyIdentifier;
      AuthorityKeyIdentifier _subDN2 = createAuthorityKeyId(var6);
      var7.addExtension(_subKP2, false, _subDN2);
      DERObjectIdentifier var10003 = X509Extensions.BasicConstraints;
      BasicConstraints _subKP3;
      _subKP3 = new BasicConstraints.<init>(_ca);
      var7.addExtension(var10003, false, _subKP3);
      X509Certificate var15 = var14.generateX509Certificate(_issKP1);
      var15.checkValidity(new Date());
      var15.verify(var6);
      return var15;
   }

   private static AuthorityKeyIdentifier createAuthorityKeyId(PublicKey _pubKey) {
      ByteArrayInputStream var1;
      var1 = new ByteArrayInputStream.<init>(_pubKey.getEncoded());
      SubjectPublicKeyInfo _pubKey1;
      _pubKey1 = new SubjectPublicKeyInfo.<init>((ASN1Sequence)(new ASN1InputStream(var1)).readObject());
      return new AuthorityKeyIdentifier(_pubKey1);
   }

   private static SubjectKeyIdentifier createSubjectKeyId(PublicKey _pubKey) {
      ByteArrayInputStream var1;
      var1 = new ByteArrayInputStream.<init>(_pubKey.getEncoded());
      SubjectPublicKeyInfo _pubKey1;
      _pubKey1 = new SubjectPublicKeyInfo.<init>((ASN1Sequence)(new ASN1InputStream(var1)).readObject());
      return new SubjectKeyIdentifier(_pubKey1);
   }

   private static BigInteger allocateSerialNumber() {
      BigInteger var10000 = serialNumber;
      serialNumber = var10000.add(BigInteger.ONE);
      return var10000;
   }
}
